#' physiology
#'
#' @name physiology-package
#' @aliases physiology
#' @keywords misc utilities
#' @concept physiology
#' @concept medicine
#' @concept renal
#' @concept blood
#' @concept ideal weight
#' @docType package
#' @useDynLib physiology, .registration = TRUE
#' @importFrom Rcpp sourceCpp
"_PACKAGE"
